package MT::Plugin::SKR::IndexRebuilder;
use strict;
use base qw( MT::Plugin );

our $PLUGIN_NAME = 'IndexRebuilder';
our $VERSION = '0.20';

my $plugin = __PACKAGE__->new({
    name     => $PLUGIN_NAME,
    version  => $VERSION,
    key      => lc $PLUGIN_NAME,
    id       => lc $PLUGIN_NAME,
    author_name => 'SKYARC System Co.,Ltd.',
    author_link => 'http://www.skyarc.co.jp/',
    description => q{<MT_TRANS phrase="IndexRebuilder">},
    l10n_class  => $PLUGIN_NAME. '::L10N',
    blog_config_template => \&blog_config_template,
    settings => MT::PluginSettings->new([
        [ 'template_id',   { Default => undef } ],
        [ 'entry_id',      { Default => undef } ],
    ]),
});

MT->add_plugin( $plugin );

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        tasks => {
            $PLUGIN_NAME => {
                name        => $PLUGIN_NAME,
                frequency   => 900,
                code        => \&_rebuilder,
            },
        },
    });
}

sub _rebuilder {
    my $pdata_iter = MT->model('plugindata')->load_iter({
        plugin => $PLUGIN_NAME,
    });

    while (my $p = $pdata_iter->()) {
        my $blog_id = $p->key;
        $blog_id =~ s{\Qconfiguration:blog:\E}{}img;

        my $blog = MT->model('blog')->lookup($blog_id) or next;

        # IndexTemplate
        next unless $p->data->{template_id};
        my @t_ids = split',',$p->data->{template_id};
        my $template = MT->model('template')->lookup_multi(\@t_ids) or next;

        for my $t (@$template){
            next unless $t;
            MT->rebuild_indexes(
                Blog      => $blog,
                Template  => $t,
                Force     => 1
            ); #or warn MT->errstr;
        }

        # entry
        next unless $p->data->{entry_id};
        my @e_ids = split',',$p->data->{entry_id};
        my $entry = MT->model('entry')->lookup_multi(\@e_ids) or next;
        for my $e (@$entry){
            next unless $e;
            MT->rebuild_entry(
                Blog        => $blog,
                Entry       => $e,
            ); #or warn MT->errstr;
        }
    }
}

sub blog_config_template {
    my ($plugin, $param, $scope) = @_;

    my $tmpl = <<__TMPL__;
<mtapp:setting id="template_id" label="<__trans phrase="template_id">">
<input type="text" size="50" name="template_id" id="template_id" value="<mt:var name="template_id">" />
</mtapp:setting>
<mtapp:setting id="entry_id" label="<__trans phrase="entry_id">">
<input type="text" size="50" name="entry_id" id="entry_id" value="<mt:var name="entry_id">" />
</mtapp:setting>
__TMPL__
    return $tmpl;
}

1;
__END__
